function y = extrapolate(Y,n,p)

% y: sequence of approximations
% n: extrapolation sequence (z.B. n=1,2,3,4)
% p: consistency rate of initial value problem

% number of extrapolation steps
k = length(n)-1;

% the interpolation polynomial is
% p(t)=a(1)*t^(p+k-1) + a(2)*t^(p+k-2) + ... + a(k)*t^p + a(k+1) 

% first, construct a large Vandermonde-matrix
v = zeros(p+k,1);
v(1:k+1) = n.^-1;
A = vander(v);

% Pick out the matrix for our polynomial interpolation
B = ones(k+1,k+1);
B(:,1:k) = A(1:k+1,1:k);

% compute the interpolation polynomial's coefficients
a = B\Y;

% extrapolate (output p(t=0))
y = a(end);

end